@@ -1,5 +1,6 @@
 import os.path
 
+
 BASEDIR = os.path.abspath(os.path.dirname(__file__))
 
 
@@ -8,11 +9,12 @@ def full_path(local_file):
 
 
 def dotname(module):
-    if not BASEDIR.endswith('tests'):
-        return 'tests.' + module
+    if not BASEDIR.endswith("tests"):
+        return f"tests.{module}"
     else:
         return module
 
+
 try:
     from saml2.sigver import get_xmlsec_binary
 except ImportError:
@@ -21,4 +23,4 @@ except ImportError:
 if get_xmlsec_binary:
     xmlsec_path = get_xmlsec_binary(["/opt/local/bin"])
 else:
-    xmlsec_path = '/usr/bin/xmlsec1'
+    xmlsec_path = "/usr/bin/xmlsec1"
