@@ -1,6 +1,7 @@
 from pathutils import full_path
 from pathutils import xmlsec_path
 
+
 CONFIG = {
     "entityid": "urn:mace:example.com:saml:roland:sp",
     "name": "urn:mace:example.com:saml:roland:sp",
@@ -8,27 +9,30 @@ CONFIG = {
     "service": {
         "sp": {
             "endpoints": {
-                "assertion_consumer_service": [
-                    "http://lingon.catalogix.se:8087/"],
+                "assertion_consumer_service": ["http://lingon.catalogix.se:8087/"],
             },
             "required_attributes": ["surName", "givenName", "mail"],
             "optional_attributes": ["title"],
             "idp": ["urn:mace:example.com:saml:roland:idp"],
             "name_id_policy_format": "urn:oasis:names:tc:SAML:2.0:nameid-format:persistent",
-            "name_id_format_allow_create": "true"
+            "name_id_format_allow_create": "true",
         }
     },
     "debug": 1,
     "key_file": full_path("test.key"),
     "cert_file": full_path("test.pem"),
-    "encryption_keypairs": [{"key_file": full_path("test_1.key"), "cert_file": full_path("test_1.crt")},
-                            {"key_file": full_path("test_2.key"), "cert_file": full_path("test_2.crt")}],
+    "encryption_keypairs": [
+        {"key_file": full_path("test_1.key"), "cert_file": full_path("test_1.crt")},
+        {"key_file": full_path("test_2.key"), "cert_file": full_path("test_2.crt")},
+    ],
     "ca_certs": full_path("cacerts.txt"),
     "xmlsec_binary": xmlsec_path,
-    "metadata": [{
-        "class": "saml2.mdstore.MetaDataFile",
-        "metadata": [(full_path("idp.xml"), ), (full_path("vo_metadata.xml"), )],
-    }],
+    "metadata": [
+        {
+            "class": "saml2.mdstore.MetaDataFile",
+            "metadata": [(full_path("idp.xml"),), (full_path("vo_metadata.xml"),)],
+        }
+    ],
     "virtual_organization": {
         "urn:mace:example.com:it:tek": {
             "nameid_format": "urn:oid:1.3.6.1.4.1.1466.115.121.1.15-NameID",
@@ -44,14 +48,14 @@ CONFIG = {
         "display_name": ("AB Exempel", "se"),
         "url": "http://www.example.org",
     },
-    "contact_person": [{
-                           "given_name": "Roland",
-                           "sur_name": "Hedberg",
-                           "telephone_number": "+46 70 100 0000",
-                           "email_address": ["tech@eample.com",
-                                             "tech@example.org"],
-                           "contact_type": "technical"
-                       },
+    "contact_person": [
+        {
+            "given_name": "Roland",
+            "sur_name": "Hedberg",
+            "telephone_number": "+46 70 100 0000",
+            "email_address": ["tech@eample.com", "tech@example.org"],
+            "contact_type": "technical",
+        },
     ],
     "logger": {
         "rotating": {
@@ -60,5 +64,5 @@ CONFIG = {
             "backupCount": 5,
         },
         "loglevel": "info",
-    }
+    },
 }
