@@ -1,20 +1,20 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+
+from pytest import raises
 
 import saml2
-
 from saml2 import saml
 from saml2 import samlp
-from saml2.validate import valid_duration, MustValueError
-from saml2.validate import valid_unsigned_short
+from saml2.validate import MustValueError
+from saml2.validate import NotValid
+from saml2.validate import valid_address
+from saml2.validate import valid_any_uri
+from saml2.validate import valid_anytype
+from saml2.validate import valid_duration
+from saml2.validate import valid_instance
 from saml2.validate import valid_non_negative_integer
 from saml2.validate import valid_string
-from saml2.validate import valid_instance
-from saml2.validate import valid_any_uri
-from saml2.validate import NotValid
-from saml2.validate import valid_anytype
-
-from py.test import raises
+from saml2.validate import valid_unsigned_short
 
 
 def _eq(l1, l2):
@@ -33,34 +33,40 @@ def test_duration():
     assert valid_duration("-P1347M")
     assert valid_duration("P1Y2MT2.5H")
 
-    raises(NotValid, 'valid_duration("P-1347M")')
-    raises(NotValid, ' valid_duration("P1Y2MT")')
-    raises(NotValid, ' valid_duration("P1Y2MT2xH")')
+    with raises(NotValid):
+        valid_duration("P-1347M")
+    with raises(NotValid):
+        valid_duration("P1Y2MT")
+    with raises(NotValid):
+        valid_duration("P1Y2MT2xH")
 
 
 def test_unsigned_short():
     assert valid_unsigned_short("1234")
 
-    raises(NotValid, ' valid_unsigned_short("-1234")')
-    raises(NotValid, ' valid_unsigned_short("1234567890")')
+    with raises(NotValid):
+        valid_unsigned_short("-1234")
+    with raises(NotValid):
+        valid_unsigned_short("1234567890")
 
 
 def test_valid_non_negative_integer():
     assert valid_non_negative_integer("1234567890")
 
-    raises(NotValid, 'valid_non_negative_integer("-123")')
-    raises(NotValid, 'valid_non_negative_integer("123.56")')
+    with raises(NotValid):
+        valid_non_negative_integer("-123")
+    with raises(NotValid):
+        valid_non_negative_integer("123.56")
     assert valid_non_negative_integer("12345678901234567890")
 
 
 def test_valid_string():
-    assert valid_string(u'example')
+    assert valid_string("example")
 
     import codecs
 
-    raises(NotValid,
-           'valid_string(codecs.getdecoder("hex_codec")'
-           '(b"02656c6c6f")[0].decode("utf-8"))')
+    with raises(NotValid):
+        valid_string(codecs.getdecoder("hex_codec")(b"02656c6c6f")[0].decode("utf-8"))
 
 
 def test_valid_anyuri():
@@ -69,11 +75,13 @@ def test_valid_anyuri():
 
 def test_valid_instance():
     attr_statem = saml.AttributeStatement()
-    text = ["value of test attribute",
-            "value1 of test attribute",
-            "value2 of test attribute",
-            "value1 of test attribute2",
-            "value2 of test attribute2", ]
+    text = [
+        "value of test attribute",
+        "value1 of test attribute",
+        "value2 of test attribute",
+        "value1 of test attribute2",
+        "value2 of test attribute2",
+    ]
 
     attr_statem.attribute.append(saml.Attribute())
     attr_statem.attribute.append(saml.Attribute())
@@ -102,7 +110,8 @@ def test_valid_instance():
     response.status = samlp.Status()
     response.assertion.append(saml.Assertion())
 
-    raises(MustValueError, 'valid_instance(response)')
+    with raises(MustValueError):
+        valid_instance(response)
 
 
 def test_valid_anytype():
@@ -113,3 +122,27 @@ def test_valid_anytype():
     assert valid_anytype("P1Y2M3DT10H30M")
     assert valid_anytype("urn:oasis:names:tc:SAML:2.0:attrname-format:uri")
 
+
+def test_valid_address():
+    assert valid_address("130.239.16.3")
+    assert valid_address("2001:8003:5555:9999:555a:5555:c77:d5c5")
+    assert valid_address("2001:8003:5555::555a:5555:c77:d5c5")
+
+    # See https://tools.ietf.org/html/rfc4038#section-5.1 regarding
+    # the inclusion of brackets in the ipv6 address below.
+    assert valid_address("[2001:8003:5555:9999:555a:5555:c77:d5c5]")
+
+    with raises(NotValid):
+        assert valid_address("127.0.0.256")
+    with raises(NotValid):
+        assert valid_address("127.0.0.")
+    with raises(NotValid):
+        assert valid_address("127.0.0")
+    with raises(NotValid):
+        assert valid_address("2001::5555:9999::5555:c77:d5c5]")
+    with raises(NotValid):
+        assert valid_address("2001:8003:5555:9999:555a:5555:c77:d5c5]")
+    with raises(NotValid):
+        assert valid_address("[2001:8003:5555:9999:555a:5555:c77:d5c5")
+    with raises(NotValid):
+        assert valid_address("[[2001:8003:5555:9999:555a:5555:c77:d5c5]")
