@@ -1,21 +1,20 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
-import sys
-import logging
-from saml2.mdstore import MetadataStore, name
+
+from pathutils import dotname
+from pathutils import full_path
 
 from saml2 import BINDING_HTTP_REDIRECT
 from saml2 import BINDING_SOAP
+from saml2.authn_context import PASSWORDPROTECTEDTRANSPORT as AUTHN_PASSWORD_PROTECTED
+from saml2.authn_context import TIMESYNCTOKEN as AUTHN_TIME_SYNC_TOKEN
 from saml2.config import Config
 from saml2.config import IdPConfig
 from saml2.config import SPConfig
-from saml2.authn_context import PASSWORDPROTECTEDTRANSPORT as AUTHN_PASSWORD_PROTECTED
-from saml2.authn_context import TIMESYNCTOKEN as AUTHN_TIME_SYNC_TOKEN
-from saml2 import logger
-
-from pathutils import dotname, full_path
-from saml2.sigver import security_context, CryptoBackendXMLSecurity
+from saml2.mdstore import MetadataStore
+from saml2.mdstore import name
+from saml2.sigver import CryptoBackendXMLSecurity
+from saml2.sigver import security_context
 
 
 sp1 = {
@@ -23,15 +22,15 @@ sp1 = {
     "service": {
         "sp": {
             "endpoints": {
-                "assertion_consumer_service": [
-                    "http://lingon.catalogix.se:8087/"],
+                "assertion_consumer_service": ["http://lingon.catalogix.se:8087/"],
             },
             "name": "test",
             "idp": {
                 "urn:mace:example.com:saml:roland:idp": {
-                    'single_sign_on_service':
-                        {'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect':
-                            'http://localhost:8088/sso/'}},
+                    "single_sign_on_service": {
+                        "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect": "http://localhost:8088/sso/"
+                    }
+                },
             },
             "requested_authn_context": {
                 "authn_context_class_ref": [
@@ -44,23 +43,24 @@ sp1 = {
     },
     "key_file": full_path("test.key"),
     "cert_file": full_path("test.pem"),
-    "metadata": [{
-        "class": "saml2.mdstore.MetaDataFile",
-        "metadata": [(full_path("metadata.xml"), ),
-                  (full_path("urn-mace-swami.se-swamid-test-1.0-metadata.xml"), )],
-    }],
+    "metadata": [
+        {
+            "class": "saml2.mdstore.MetaDataFile",
+            "metadata": [(full_path("metadata.xml"),), (full_path("urn-mace-swami.se-swamid-test-1.0-metadata.xml"),)],
+        }
+    ],
     "virtual_organization": {
         "coip": {
             "nameid_format": "urn:oasis:names:tc:SAML:2.0:nameid-format:transient",
             "common_identifier": "eduPersonPrincipalName",
             "attribute_auth": [
                 "https://coip-test.sunet.se/idp/shibboleth",
-            ]
+            ],
         }
     },
     "attribute_map_dir": full_path("attributemaps"),
     "only_use_keys_in_metadata": True,
-    "xmlsec_path": ["/opt/local/bin"]
+    "xmlsec_path": ["/opt/local/bin"],
 }
 
 sp2 = {
@@ -69,8 +69,7 @@ sp2 = {
     "service": {
         "sp": {
             "endpoints": {
-                "assertion_consumer_service": [
-                    "http://lingon.catalogix.se:8087/"],
+                "assertion_consumer_service": ["http://lingon.catalogix.se:8087/"],
             },
             "required_attributes": ["surName", "givenName", "mail"],
             "optional_attributes": ["title"],
@@ -82,7 +81,7 @@ sp2 = {
             "force_authn": True,
         }
     },
-    #"xmlsec_binary" : "/opt/local/bin/xmlsec1",
+    # "xmlsec_binary" : "/opt/local/bin/xmlsec1",
 }
 
 IDP1 = {
@@ -102,11 +101,12 @@ IDP1 = {
                         "mail": [".*@example.com"],
                     }
                 },
-                "urn:mace:umu.se:saml:roland:sp": None
+                "urn:mace:umu.se:saml:roland:sp": None,
             },
+            "error_url": "http://localhost:8080/error",
         }
     },
-    #"xmlsec_binary" : "/usr/local/bin/xmlsec1",
+    # "xmlsec_binary" : "/usr/local/bin/xmlsec1",
 }
 
 IDP2 = {
@@ -116,8 +116,7 @@ IDP2 = {
         "idp": {
             "endpoints": {
                 "single_sign_on_service": ["http://localhost:8088/"],
-                "single_logout_service": [
-                    ("http://localhost:8088/", BINDING_HTTP_REDIRECT)],
+                "single_logout_service": [("http://localhost:8088/", BINDING_HTTP_REDIRECT)],
             },
             "policy": {
                 "default": {
@@ -128,11 +127,11 @@ IDP2 = {
                         "mail": [".*@example.com"],
                     }
                 },
-                "urn:mace:umu.se:saml:roland:sp": None
+                "urn:mace:umu.se:saml:roland:sp": None,
             },
         }
     },
-    #"xmlsec_binary" : "/usr/local/bin/xmlsec1",
+    # "xmlsec_binary" : "/usr/local/bin/xmlsec1",
 }
 
 PDP = {
@@ -141,8 +140,7 @@ PDP = {
     "service": {
         "pdp": {
             "endpoints": {
-                "authz_service": [("http://example.org/pysaml2/pdp/authz",
-                                   BINDING_SOAP)],
+                "authz_service": [("http://example.org/pysaml2/pdp/authz", BINDING_SOAP)],
             },
         }
     },
@@ -153,12 +151,13 @@ PDP = {
         "display_name": [("Exempel AB", "se"), ("Example Co.", "en")],
         "url": "http://www.example.com/roland",
     },
-    "contact_person": [{
-                           "given_name": "John",
-                           "sur_name": "Smith",
-                           "email_address": ["john.smith@example.com"],
-                           "contact_type": "technical",
-                       },
+    "contact_person": [
+        {
+            "given_name": "John",
+            "sur_name": "Smith",
+            "email_address": ["john.smith@example.com"],
+            "contact_type": "technical",
+        },
     ],
 }
 
@@ -168,15 +167,14 @@ ECP_SP = {
     "service": {
         "sp": {
             "endpoints": {
-                "assertion_consumer_service": [
-                    "http://lingon.catalogix.se:8087/"],
+                "assertion_consumer_service": ["http://lingon.catalogix.se:8087/"],
             },
             "ecp": {
                 "130.239.": "http://example.com/idp",
-            }
+            },
         }
     },
-    #"xmlsec_binary" : "/opt/local/bin/xmlsec1",
+    # "xmlsec_binary" : "/opt/local/bin/xmlsec1",
 }
 
 IDP_XMLSECURITY = {
@@ -186,8 +184,7 @@ IDP_XMLSECURITY = {
         "idp": {
             "endpoints": {
                 "single_sign_on_service": ["http://localhost:8088/"],
-                "single_logout_service": [
-                    ("http://localhost:8088/", BINDING_HTTP_REDIRECT)],
+                "single_logout_service": [("http://localhost:8088/", BINDING_HTTP_REDIRECT)],
             },
             "policy": {
                 "default": {
@@ -198,12 +195,12 @@ IDP_XMLSECURITY = {
                         "mail": [".*@example.com"],
                     }
                 },
-                "urn:mace:umu.se:saml:roland:sp": None
+                "urn:mace:umu.se:saml:roland:sp": None,
             },
         }
     },
     "key_file": "pkcs11:///usr/lunasa/lib/libCryptoki2_64.so:1/eduID dev SAML signing key?pin=123456",
-    "crypto_backend": "XMLSecurity"
+    "crypto_backend": "XMLSecurity",
 }
 
 
@@ -225,10 +222,8 @@ def test_1():
     assert list(c._sp_idp.keys()) == ["urn:mace:example.com:saml:roland:idp"]
     assert list(c._sp_idp.values()) == [
         {
-            'single_sign_on_service': {
-                'urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect': (
-                    'http://localhost:8088/sso/'
-                )
+            "single_sign_on_service": {
+                "urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect": ("http://localhost:8088/sso/")
             }
         }
     ]
@@ -236,8 +231,8 @@ def test_1():
     assert c.only_use_keys_in_metadata
     assert type(c.getattr("requested_authn_context")) is dict
     assert c.getattr("requested_authn_context").get("authn_context_class_ref") == [
-            AUTHN_PASSWORD_PROTECTED,
-            AUTHN_TIME_SYNC_TOKEN,
+        AUTHN_PASSWORD_PROTECTED,
+        AUTHN_TIME_SYNC_TOKEN,
     ]
     assert c.getattr("requested_authn_context").get("comparison") == "exact"
 
@@ -256,8 +251,7 @@ def test_2():
 
     assert len(c._sp_idp) == 1
     assert list(c._sp_idp.keys()) == [""]
-    assert list(c._sp_idp.values()) == [
-        "https://example.com/saml2/idp/SSOService.php"]
+    assert list(c._sp_idp.values()) == ["https://example.com/saml2/idp/SSOService.php"]
     assert c.only_use_keys_in_metadata is True
 
 
@@ -275,7 +269,7 @@ def test_minimum():
                 },
             }
         },
-        #"xmlsec_binary" : "/usr/local/bin/xmlsec1",
+        # "xmlsec_binary" : "/usr/local/bin/xmlsec1",
     }
 
     c = SPConfig().load(minimum)
@@ -289,25 +283,24 @@ def test_idp_1():
     c.context = "idp"
 
     print(c)
-    assert c.endpoint("single_sign_on_service")[0] == 'http://localhost:8088/'
+    assert c.endpoint("single_sign_on_service")[0] == "http://localhost:8088/"
 
-    attribute_restrictions = c.getattr("policy",
-                                       "idp").get_attribute_restrictions("")
+    attribute_restrictions = c.getattr("policy", "idp").get_attribute_restrictions("")
     assert attribute_restrictions["edupersonaffiliation"][0].match("staff")
 
+    error_url = c.getattr("error_url", "idp")
+    assert error_url == "http://localhost:8080/error"
+
 
 def test_idp_2():
     c = IdPConfig().load(IDP2)
     c.context = "idp"
 
     print(c)
-    assert c.endpoint("single_logout_service",
-                      BINDING_SOAP) == []
-    assert c.endpoint("single_logout_service",
-                      BINDING_HTTP_REDIRECT) == ["http://localhost:8088/"]
+    assert c.endpoint("single_logout_service", BINDING_SOAP) == []
+    assert c.endpoint("single_logout_service", BINDING_HTTP_REDIRECT) == ["http://localhost:8088/"]
 
-    attribute_restrictions = c.getattr("policy",
-                                       "idp").get_attribute_restrictions("")
+    attribute_restrictions = c.getattr("policy", "idp").get_attribute_restrictions("")
     assert attribute_restrictions["edupersonaffiliation"][0].match("staff")
 
 
@@ -317,8 +310,8 @@ def test_wayf():
 
     idps = c.metadata.with_descriptor("idpsso")
     ent = list(idps.values())[0]
-    assert name(ent) == 'Example Co.'
-    assert name(ent, "se") == 'Exempel AB'
+    assert name(ent) == "Example Co."
+    assert name(ent, "se") == "Exempel AB"
 
 
 def test_conf_syslog():
@@ -333,7 +326,7 @@ def test_3():
     assert cnf.debug == 1
     assert cnf.key_file == full_path("test.key")
     assert cnf.cert_file == full_path("test.pem")
-    #assert cnf.xmlsec_binary ==  "/usr/local/bin/xmlsec1"
+    # assert cnf.xmlsec_binary ==  "/usr/local/bin/xmlsec1"
     assert cnf.accepted_time_diff == 60
     assert cnf.secret == "0123456789"
     assert cnf.metadata is not None
@@ -344,8 +337,7 @@ def test_3():
 def test_sp():
     cnf = SPConfig()
     cnf.load_file(dotname("sp_1_conf"))
-    assert cnf.endpoint("assertion_consumer_service") == \
-           ["http://lingon.catalogix.se:8087/"]
+    assert cnf.endpoint("assertion_consumer_service") == ["http://lingon.catalogix.se:8087/"]
 
 
 def test_dual():
@@ -361,8 +353,7 @@ def test_dual():
 def test_ecp():
     cnf = SPConfig()
     cnf.load(ECP_SP)
-    assert cnf.endpoint("assertion_consumer_service") == \
-           ["http://lingon.catalogix.se:8087/"]
+    assert cnf.endpoint("assertion_consumer_service") == ["http://lingon.catalogix.se:8087/"]
     eid = cnf.ecp_endpoint("130.239.16.3")
     assert eid == "http://example.com/idp"
     eid = cnf.ecp_endpoint("130.238.20.20")
@@ -379,26 +370,26 @@ def test_assertion_consumer_service():
     entity_id = "https://www.zimride.com/shibboleth"
     acs = c.metadata.assertion_consumer_service(entity_id)
     assert len(acs) == 1
-    assert acs[0][
-        "location"] == 'https://www.zimride.com/Shibboleth.sso/SAML2/POST'
+    assert acs[0]["location"] == "https://www.zimride.com/Shibboleth.sso/SAML2/POST"
 
 
 def test_crypto_backend():
     idpc = IdPConfig()
     idpc.load(IDP_XMLSECURITY)
 
-    assert idpc.crypto_backend == 'XMLSecurity'
+    assert idpc.crypto_backend == "XMLSecurity"
     sec = security_context(idpc)
     assert isinstance(sec.crypto, CryptoBackendXMLSecurity)
 
+
 def test_unset_force_authn():
     cnf = SPConfig().load(sp1)
-    assert bool(cnf.getattr('force_authn', 'sp')) == False
+    assert bool(cnf.getattr("force_authn", "sp")) == False
 
 
 def test_set_force_authn():
     cnf = SPConfig().load(sp2)
-    assert bool(cnf.getattr('force_authn', 'sp')) == True
+    assert bool(cnf.getattr("force_authn", "sp")) == True
 
 
 if __name__ == "__main__":
